@@ -6,6 +6,7 @@ from skfem.mapping import MappingMortar
 from skfem.mesh import Mesh
 
 from .boundary_facet_basis import BoundaryFacetBasis
+from ..dofs import Dofs
 
 
 class MortarFacetBasis(BoundaryFacetBasis):
@@ -17,7 +18,8 @@ class MortarFacetBasis(BoundaryFacetBasis):
                  intorder: Optional[int] = None,
                  quadrature: Optional[Tuple[ndarray, ndarray]] = None,
                  facets: Optional[ndarray] = None,
-                 side: int = 0):
+                 side: int = 0,
+                 dofs: Optional[Dofs] = None):
         """Precomputed global basis on the mortar mesh."""
 
         if side not in (0, 1):
@@ -33,4 +35,5 @@ class MortarFacetBasis(BoundaryFacetBasis):
                                                intorder=intorder,
                                                quadrature=quadrature,
                                                facets=facets,
-                                               _side=0)
+                                               _side=0,
+                                               dofs=dofs)
