@@ -1,3 +1,4 @@
+import logging
 from typing import Optional, Tuple
 from threading import Thread
 from itertools import product
@@ -11,6 +12,9 @@ from .coo_data import COOData
 from .form import Form, FormExtraParams
 
 
+logger = logging.getLogger(__name__)
+
+
 class BilinearForm(Form):
     """A bilinear form for finite element assembly.
 
@@ -71,9 +75,6 @@ class BilinearForm(Form):
         wdict = FormExtraParams({
             **ubasis.default_parameters(),
             **self.dictify(kwargs, ubasis),
-            'sign': ubasis._sign,
-            'sign1': ubasis._sign,
-            'sign2': vbasis._sign,
         })
 
         # initialize COO data structures
@@ -141,7 +142,11 @@ class BilinearForm(Form):
             Any additional keyword arguments are appended to ``w``.
 
         """
-        return COOData._assemble_scipy_csr(*self._assemble(*args, **kwargs))
+        assert self.form is not None
+        logger.info("Assembling '{}'.".format(self.form.__name__))
+        mat = COOData._assemble_scipy_csr(*self._assemble(*args, **kwargs))
+        logger.info("Assembling finished.")
+        return mat
 
     def _kernel(self, u, v, w, dx):
         return np.sum(self.form(*u, *v, w) * dx, axis=1)
