@@ -1,7 +1,8 @@
 """This module contains utility functions such as convenient access to
 SciPy linear solvers."""
 
-import warnings
+import logging
+from warnings import warn
 from typing import Optional, Union, Tuple, Callable, Dict
 
 import numpy as np
@@ -16,6 +17,9 @@ from skfem.assembly.basis import AbstractBasis
 from skfem.element import ElementVector
 
 
+logger = logging.getLogger(__name__)
+
+
 # custom types for describing input and output values
 
 
@@ -143,7 +147,7 @@ def solver_iter_krylov(krylov: Optional[LinearSolver] = spl.cg,
             kwargs['M'] = build_pc_diag(A)
         sol, info = krylov(A, b, **{'callback': callback, **kwargs})
         if info > 0:
-            warnings.warn("Convergence not achieved!")
+            logger.warning("Iterative solver did not converge.")
         elif info == 0 and verbose:
             print(f"{krylov.__name__} converged to "
                   + f"tol={kwargs.get('tol', 'default')} and "
@@ -220,11 +224,15 @@ def solve(A: spmatrix,
         :func:`skfem.utils.solver_iter_krylov`.
 
     """
+    logger.info("Solving linear system, shape={}.".format(A.shape))
     if isinstance(b, spmatrix):
-        return solve_eigen(A, b, x, I, solver, **kwargs)  # type: ignore
+        out = solve_eigen(A, b, x, I, solver, **kwargs)  # type: ignore
     elif isinstance(b, ndarray):
-        return solve_linear(A, b, x, I, solver, **kwargs)  # type: ignore
-    raise NotImplementedError("Provided argument types not supported")
+        out = solve_linear(A, b, x, I, solver, **kwargs)  # type: ignore
+    else:
+        raise NotImplementedError("Provided argument types not supported")
+    logger.info("Solving done.")
+    return out
 
 
 def _flatten_dofs(S: Optional[DofsCollection]) -> Optional[ndarray]:
@@ -652,8 +660,8 @@ def project(fun,
             diff: Optional[int] = None,
             I: Optional[ndarray] = None,
             expand: bool = False) -> ndarray:
-    warnings.warn("project is deprecated in favor of projection.",
-                  DeprecationWarning)
+    warn("project is deprecated in favor of projection.",
+         DeprecationWarning)
     return projection(
         fun,
         basis_to=basis_to,
